@@ -46,6 +46,7 @@ class GraphicsEditorWidget(QtWidgets.QWidget):
         self._ui.face_enumeration_chooser.setEnumsList(Element.FaceTypeEnumToString, Element.FaceTypeEnumFromString)
         self._ui.scenecoordinatesystem_chooser.setEnumsList(ScenecoordinatesystemEnumToString, ScenecoordinatesystemEnumFromString)
         self._ui.boundarymode_chooser.setEnumsList(Graphics.BoundaryModeEnumToString, Graphics.BoundaryModeEnumFromString)
+        self._ui.domain_chooser.setEnumsList(Field.DomainTypeEnumToString, Field.DomainTypeEnumFromString)
         self._ui.streamlines_track_direction_chooser.setEnumsList(GraphicsStreamlines.TrackDirectionEnumToString, GraphicsStreamlines.TrackDirectionEnumFromString) 
         self._ui.streamlines_colour_data_type_chooser.setEnumsList(GraphicsStreamlines.ColourDataTypeEnumToString, GraphicsStreamlines.ColourDataTypeEnumFromString)
         self._ui.line_shape_chooser.setEnumsList(Graphicslineattributes.ShapeTypeEnumToString, Graphicslineattributes.ShapeTypeEnumFromString)
@@ -73,8 +74,6 @@ class GraphicsEditorWidget(QtWidgets.QWidget):
         self._ui.label_field_chooser.setNullObjectName('-')
         self._ui.sampling_mode_chooser.setEnumsList(Element.PointSamplingModeEnumToString, Element.PointSamplingModeEnumFromString)
 
-        
-
     def _updateWidgets(self):
         # base graphics attributes
         subgroupField = None
@@ -182,6 +181,8 @@ class GraphicsEditorWidget(QtWidgets.QWidget):
     def setScene(self, scene):
         """
         Set when scene changes to initialised widgets dependent on scene
+
+        :param scene: zinc.scene
         """
         self._ui.material_chooser.setMaterialmodule(scene.getMaterialmodule())
         self._ui.glyph_chooser.setGlyphmodule(scene.getGlyphmodule())
@@ -206,6 +207,8 @@ class GraphicsEditorWidget(QtWidgets.QWidget):
     def setGraphics(self, graphics):
         """
         Set the graphics to be edited
+
+        :param graphics: zinc.graphics.
         """
         if graphics and graphics.isValid():
             self._graphics = graphics
@@ -264,6 +267,8 @@ class GraphicsEditorWidget(QtWidgets.QWidget):
     def subgroupFieldChanged(self, index):
         """
         An item was selected at index in subgroup field chooser widget
+
+        :param index: index of new item.
         """
         if self._graphics:
             subgroupField = self._ui.subgroup_field_chooser.getField()
@@ -275,6 +280,8 @@ class GraphicsEditorWidget(QtWidgets.QWidget):
     def coordinateFieldChanged(self, index):
         """
         An item was selected at index in coordinate field chooser widget
+
+        :param index: index of new item.
         """
         if self._graphics:
             coordinateField = self._ui.coordinate_field_chooser.getField()
@@ -300,6 +307,8 @@ class GraphicsEditorWidget(QtWidgets.QWidget):
     def dataFieldChanged(self, index):
         """
         An item was selected at index in data field chooser widget
+
+        :param index: index of new item.
         """
         if self._graphics:
             dataField = self._ui.data_field_chooser.getField()
@@ -328,6 +337,8 @@ class GraphicsEditorWidget(QtWidgets.QWidget):
     def tessellationChanged(self, index):
         """
         An item was selected at index in tessellation chooser widget
+
+        :param index: index of new item.
         """
         if self._graphics:
             tessellation = self._ui.tessellation_chooser.getTessellation()
@@ -342,7 +353,17 @@ class GraphicsEditorWidget(QtWidgets.QWidget):
             boundarymode = self._graphics.getBoundaryMode()
         self._ui.boundarymode_chooser.setEnum(boundarymode)
 
+    def domainChanged(self, index):
+        if self._graphics:
+            domain = self._ui.boundarymode_chooser.getEnum()
+            self._graphics.setDomain(domain)
+
     def boundarymodeChanged(self, index):
+        """
+        Change the current state of the boundarymode enumeration chooser
+
+        :param index: The index of boundarymode enumeration after change.
+        """
         if self._graphics:
             boundarymode = self._ui.boundarymode_chooser.getEnum()
             self._graphics.setBoundaryMode(boundarymode)
@@ -359,6 +380,8 @@ class GraphicsEditorWidget(QtWidgets.QWidget):
     def faceChanged(self, index):
         """
         Element face combo box changed
+
+        :param index: index of new item.
         """
         if self._graphics:
             faceType = self._ui.face_enumeration_chooser.getEnum()
@@ -367,6 +390,8 @@ class GraphicsEditorWidget(QtWidgets.QWidget):
     def wireframeClicked(self, isChecked):
         """
         The wireframe surface render radiobutton was clicked
+
+        :param isChecked: boolean
         """
         if self._graphics:
             self._graphics.setRenderPolygonMode(Graphics.RENDER_POLYGON_MODE_WIREFRAME if isChecked else Graphics.RENDER_POLYGON_MODE_SHADED)
@@ -374,6 +399,8 @@ class GraphicsEditorWidget(QtWidgets.QWidget):
     def glyphChanged(self, index):
         """
         An item was selected at index in glyph chooser widget
+
+        :param index: index of new item.
         """
         if self._graphics:
             pointattributes = self._graphics.getGraphicspointattributes()
@@ -387,6 +414,8 @@ class GraphicsEditorWidget(QtWidgets.QWidget):
     def materialChanged(self, index):
         """
         An item was selected at index in material chooser widget
+
+        :param index: index of new item.
         """
         if self._graphics:
             material = self._ui.material_chooser.getMaterial()
@@ -480,6 +509,8 @@ class GraphicsEditorWidget(QtWidgets.QWidget):
     def streamlinesTrackDirectionChanged(self, index):
         """
         Element streamlines track direction combo box changed
+
+        :param index: index of new item.
         """
         if self._graphics:
             streamlines = self._graphics.castStreamlines()
@@ -500,6 +531,8 @@ class GraphicsEditorWidget(QtWidgets.QWidget):
     def streamlinesColourDataTypeChanged(self, index):
         """
         Element streamlines colour data type combo box changed
+
+        :param index: index of new item.
         """
         if self._graphics:
             streamlines = self._graphics.castStreamlines()
@@ -528,6 +561,8 @@ class GraphicsEditorWidget(QtWidgets.QWidget):
     def lineShapeChanged(self, index):
         """
         Element lineShape combo box changed
+
+        :param index: index of new item.
         """
         if self._graphics:
             lineattributes = self._graphics.getGraphicslineattributes()
